
from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from sqlalchemy.orm import sessionmaker
import random

app = Flask(__name__)
app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///example.db'
db = SQLAlchemy(app)

class User(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(80), unique=True, nullable=False)
    email = db.Column(db.String(120), unique=True, nullable=False)

def add_user(username, email):
    new_user = User(username=username, email=email)
    db.session.add(new_user)
    db.session.commit()

def get_user_by_id(user_id):
    return User.query.get(user_id)

def update_user_email(user_id, new_email):
    user = get_user_by_id(user_id)
    if user:
        user.email = new_email
        db.session.commit()

def delete_user(user_id):
    user = get_user_by_id(user_id)
    if user:
        db.session.delete(user)
        db.session.commit()

# Create database and tables
@app.before_first_request
def create_tables():
    db.create_all()

# Flask app context
with app.app_context():
    # Add a new user
    add_user('JohnDoe', 'johndoe@example.com')
    # Get a user by ID
    user = get_user_by_id(1)
    # Update user's email
    update_user_email(1, 'newjohndoe@example.com')
    # Delete a user
    delete_user(1)



